function C = modulo_tangente_SaintVenant_Kirchhoff(Y,nu)
% Slido hiperelstico de Saint Venant-Kirchhoff
% C = modulo_tangente_SaintVenant_Kirchhoff(E)
% C = [C1111 C1122 C1133 C1112 C1123 C1131
%      C2211 C2222 C2233 C2212 C2223 C2231
%      C3311 C3322 C3333 C3312 C3323 C3331
%      C1211 C1222 C1233 C1212 C1223 C1231
%      C2311 C2322 C2333 C2312 C2323 C2331
%      C3111 C3122 C3133 C3112 C3123 C3131];
% Cijkl = derivada de Tij con respecto a Ekl
% Tij = Tji: Segundo tensor de tension de Piola-Kirchhoff
% Eij = Eji: Tensor de deformacin de Green-Lagrange

c = Y * (1 - nu) / (1 + nu) / (1 - 2 * nu);
c1 = nu / (1 - nu) * c;
c2 = Y / (nu + 1.0) / 2;

C = [ 
    c c1 c1 0  0  0
    c1 c c1 0  0  0
    c1 c1 c 0  0  0
    0  0  0 c2 0  0
    0  0  0 0  c2 0
    0  0  0 0  0  c2
    ];